        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 18 <strong>control</strong><br>0,1,2,3,7,14,15,17,29,30,32,38,40,41,43,44,45,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>37</strong> miembros: 13 <br>5,8,11,13,16,23,25,28,33,35,37,39,46';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>9</strong> miembros: 12 <br>4,6,9,21,22,24,26,27,42,47,48,49';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 8 <br>10,12,18,19,20,31,34,36';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 18 <strong>control</strong><br>0,1,2,3,7,14,15,17,29,30,32,38,40,41,43,44,45,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>37</strong> miembros: 13 <br>5,8,11,13,16,23,25,28,33,35,37,39,46';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>9</strong> miembros: 12 <br>4,6,9,21,22,24,26,27,42,47,48,49';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 8 <br>10,12,18,19,20,31,34,36';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 18 <strong>control</strong><br>0,1,2,3,7,14,15,17,29,30,32,38,40,41,43,44,45,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>37</strong> miembros: 13 <br>5,8,11,13,16,23,25,28,33,35,37,39,46';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>9</strong> miembros: 12 <br>4,6,9,21,22,24,26,27,42,47,48,49';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 8 <br>10,12,18,19,20,31,34,36';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 18 <strong>control</strong><br>0,1,2,3,7,14,15,17,29,30,32,38,40,41,43,44,45,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>37</strong> miembros: 13 <br>5,8,11,13,16,23,25,28,33,35,37,39,46';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>9</strong> miembros: 12 <br>4,6,9,21,22,24,26,27,42,47,48,49';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 8 <br>10,12,18,19,20,31,34,36';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 18 <strong>control</strong><br>0,1,2,3,7,14,15,17,29,30,32,38,40,41,43,44,45,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>37</strong> miembros: 13 <br>5,8,11,13,16,23,25,28,33,35,37,39,46';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>9</strong> miembros: 12 <br>4,6,9,21,22,24,26,27,42,47,48,49';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>4</strong> representante: <strong>10</strong> miembros: 8 <br>10,12,18,19,20,31,34,36';}
}
